@@ -1,16 +1,17 @@
 package Benchmark::Perl::Formance;
-# git description: v0.34-6-g361ec8a
+# git description: v0.35-9-g372eda2
 
 BEGIN {
   $Benchmark::Perl::Formance::AUTHORITY = 'cpan:SCHWIGON';
 }
-$Benchmark::Perl::Formance::VERSION = '0.35';
+$Benchmark::Perl::Formance::VERSION = '0.36';
 use 5.008;
 
 use warnings;
 use strict;
 
 use Config;
+use Config::Perl::V;
 use Exporter;
 use Getopt::Long ":config", "no_ignore_case", "bundling";
 use Data::Structure::Util "unbless";
@@ -22,6 +23,7 @@ use Data::DPath 'dpath', 'dpathi';
 use File::Find;
 use Storable "fd_retrieve", "store_fd";
 use Sys::Hostname;
+use Sys::Info;
 use FindBin qw($Bin);
 
 # comma separated list of default plugins
@@ -68,6 +70,7 @@ my $ALL_PLUGINS = join ",", qw(DPath
                              );
 
 our $scaling_script = "$Bin/benchmark-perlformance-set-stable-system";
+our $metric_prefix  = "perlformance.perl5";
 
 our $DEFAULT_INDENT          = 0;
 
@@ -396,6 +399,40 @@ sub _get_perl_config {
         return map { ("perlconfig_$_" => $Config{$_}) } @cfgkeys;
 }
 
+sub _get_perl_config_v {
+        my ($self) = @_;
+
+        # only when ultimate verbose config requested
+        return unless $self->{options}{showconfig} >= 5;
+
+        my $config_v_myconfig = Config::Perl::V::myconfig ();
+        my @config_v_keys = sort keys %$config_v_myconfig;
+
+        # --- flat configs ---
+        my $prefix      = "perlconfigv";
+        my %perlconfigv = ();
+        my %focus       = (
+                           derived     => [ qw( Off_t uname) ],
+                           build       => [ qw( osname stamp ) ],
+                           environment => [ keys %{$config_v_myconfig->{environment}} ], # all
+                    );
+        foreach my $subcfg (keys %focus) {
+                foreach my $k (@{$focus{$subcfg}}) {
+                        $perlconfigv{join("_", $prefix, $subcfg, $k)} = $config_v_myconfig->{$subcfg}{$k};
+                }
+        }
+
+        # --- nested configs ---
+
+        # build options
+        my @buildoptionkeys = keys %{$config_v_myconfig->{build}{options}};
+        foreach my $k (keys %focus) {
+                $perlconfigv{join("_", $prefix, "build", "options", $k)} = $config_v_myconfig->{build}{options}{$k};
+        }
+
+        return %perlconfigv;
+}
+
 sub _get_perlformance_config {
         my ($self) = @_;
 
@@ -417,6 +454,26 @@ sub _get_platforminfo {
         return %$get_info;
 }
 
+sub _get_sysinfo {
+        my ($self) = @_;
+
+        my %sysinfo = ();
+        my $prefix = "sysinfo";
+        my $cpu = (Sys::Info->new->device("CPU")->identify)[0];
+        $sysinfo{join("_", $prefix, "cpu", $_)} = $cpu->{$_} foreach qw(name
+                                                                        family
+                                                                        model
+                                                                        stepping
+                                                                        architecture
+                                                                        number_of_cores
+                                                                        number_of_logical_processors
+                                                                        architecture
+                                                                        manufacturer
+                                                                      );
+        $sysinfo{join("_", $prefix, "cpu", "l2_cache", "max_cache_size")} = $cpu->{L2_cache}{max_cache_size};
+        return %sysinfo;
+}
+
 sub augment_results_with_meta {
         my ($self, $NAME_KEY, $VALUE_KEY, $META, $RESULTS) = @_;
 
@@ -425,7 +482,7 @@ sub augment_results_with_meta {
         foreach my $plugin (sort @run_plugins) {
                 no strict 'refs'; ## no critic
                 my $res = $self->_plugin_results($plugin, $RESULTS);
-                my $benchmark =  $self->{options}{fastmode} ? "$plugin(F)" : $plugin;
+                my $benchmark =  join ".", $metric_prefix, ($self->{options}{fastmode} ? "$plugin(F)" : $plugin);
                 push @new_entries, {
                                     %$META,
                                     # metric name and value at last position to override
@@ -460,6 +517,8 @@ sub generate_BenchmarkAnythingData_data
                      %prefixed_codespeed_meta,
                      $self->_get_bootstrap_perl_meta,
                      $self->_get_perl_config,
+                     $self->_get_perl_config_v,
+                     $self->_get_sysinfo,
                      $self->_get_perlformance_config,
                     );
         return $self->augment_results_with_meta("NAME", "VALUE", \%META, $RESULTS);
@@ -577,16 +636,19 @@ sub run {
         # Perl Config
         if ($showconfig)
         {
+                # Config
                 my @cfgkeys;
                 push @cfgkeys, @{$CONFIG_KEYS{$_}} foreach 1..$showconfig;
                 $RESULTS{perl_config} =
                 {
                  map { $_ => $Config{$_} } sort @cfgkeys
                 };
+
+                # Config::Perl::V
+                $RESULTS{perl_config_v} = Config::Perl::V::myconfig;
         }
 
         # Perl Config
-        my $platform_info = Devel::Platform::Info->new->get_info;
         if ($platforminfo)
         {
                 $RESULTS{platform_info} = { $self->_get_platforminfo };
@@ -623,6 +685,15 @@ sub print_outstyle_yaml
         print $output;
 }
 
+sub print_outstyle_json
+{
+        my ($self, $RESULTS) = @_;
+
+        require JSON;
+        my $json = JSON->new->allow_nonref;
+        print $json->pretty->encode( $RESULTS );
+}
+
 sub find_interesting_result_paths
 {
         my ($self, $RESULTS) = @_;
@@ -652,12 +723,13 @@ sub print_outstyle_summary
 
         my @run_plugins = $self->find_interesting_result_paths($RESULTS);
         my $len = max map { length } @run_plugins;
+        $len   += 1+length($metric_prefix);
 
         foreach (sort @run_plugins) {
                 no strict 'refs'; ## no critic
                 my @resultkeys = split(/\./);
                 my ($res) = dpath("/results/".join("/", map { qq("$_") } @resultkeys)."/Benchmark/*[0]")->match($RESULTS);
-                print sprintf("%-${len}s : %f\n", $_, ($res || 0));
+                print sprintf("%-${len}s : %f\n", join(".", $metric_prefix, $_), ($res || 0));
         }
 }
 
@@ -667,7 +739,7 @@ sub print_results
         return if $self->{options}{quiet};
 
         my $outstyle = $self->{options}{outstyle};
-        $outstyle = "summary" unless $outstyle =~ qr/^(summary|yaml)$/;
+        $outstyle = "summary" unless $outstyle =~ qr/^(summary|yaml|json)$/;
         my $sub = "print_outstyle_$outstyle";
 
         $self->$sub($RESULTS);
